@@ -4,7 +4,7 @@ use warnings;
 package Util::H2O::More;
 use parent q/Exporter/;
 
-our $VERSION = q{0.0.7};
+our $VERSION = q{0.0.8};
 
 our @EXPORT_OK = (qw/baptise opt2h2o h2o o2h/);
 
@@ -68,7 +68,13 @@ sub opt2h2o(@) {
 
 # return a dereferences hash (non-recursive); reverse of `h2o'
 sub o2h {
-  return Util::H2O::o2h @_;
+    # makes internal package name more generic for baptise created references
+    $Util::H2O::_PACKAGE_REGEX = qr/::_[0-9A-Fa-f]+\z/;
+    my $ref = Util::H2O::o2h @_;
+    if ( ref $ref ne q{HASH} ) {
+      die qq{Could not fully remove top-level reference. Probably an issue with \$Util::H2O_PACKAGE_REGEX\n};
+    }
+    return $ref;
 }
 
 1;
@@ -83,7 +89,7 @@ uses C<Util::H2O::h2o> as the basis for actual object creation;
 but there's no reason other accessor makers couldn't have been
 used or can be used. I just really like C<h2o>. :-)
 
-NOTE: C<baptise_deeply> is be removed favour of properly handling
+NOTE: C<baptise_deeply> has been removed favour of properly handling
 the C<-recurse> subroutine flag. Also, this is longer experimental.
 
 =head1 SYNOPSIS
@@ -161,7 +167,7 @@ I wanted a I<better bless>.
 
 The long answer...
 
-C<h2o> is an deceptively powerful tool that, above all, makes
+C<h2o> is a deceptively powerful tool that, above all, makes
 it I<easy> and I<fun> to add accessors to ad hoc hash references
 that many Perl developers like to use and that get emitted,
 I<unblessed> by many popular modules. For example, C<HTTP::Tiny>,
@@ -228,51 +234,19 @@ will work perfectly well with C<baptise> and friends.
 
 =item C<o2h REF>
 
-Effectively, the inverse of C<h2o> or C<baptise>; please
-note that it only returns the hash keys and their values;
-it doesn't do anything with accessors that have not caused
-keys to autovivify in the underlying hash reference.
+Uses C<Util::H2O::o2h>, so behaves identical to it.  A new hash reference
+is returned, unlike C<h2o> or C<baptise>. See C<Util::H2O>'s POD for
+a lot more information.
 
-Note: although the blessed reference is passed I<by reference>,
-the unblessed hash is B<return>; leaving the original reference
-unaffected. See examples below.
+This method complements C<h2o> or C<baptise> very well in the sitution,
+e.g., when one is dealing with an ad hoc object that then needs to be
+sent as a serialzied JSON string. It's convenient to be able to get
+the un<bless>'d data structure most JSON encoding methods are expecting.
 
-Given a non-nested object reference; such as one created by
-C<h2o> or C<baptise>, returns a reference to a pure hash void
-of the virtually indelible mark of the package name.
+Implementation note:
 
-    my $origin_ref    = { ... };
-    h2o -recurse, $origin_ref;             # Note: h2o affects the hash reference, but also returns it
-    my $pure_hash_ref = o2h $object_ref;   # Note: original reference is unaffected
-    
-    # Test::More
-    is_deeply $origin_ref, $pure_hash_ref, q{o2h completely undoes h2o};
-
-=item C<o2h -recurse, REF>
-
-Like C<o2h>, but for nested objects created with C<h2o -recurse>
-or C<baptise -recurse>.
-
-    my $origin_ref    = { ... };
-    h2o -recurse, $origin_ref;                     # Note: h2o affects the hash reference, but also returns it
-    my $pure_hash_ref = o2h -recurse, $object_ref; # Note: original reference is unaffected
-    
-    # Test::More ..
-    is_deeply $origin_ref, $pure_hash_ref, q{o2h completely undoes h2o};
-
-Again, this is inverse operation of C<h2o -recurse> or
-C<baptise -recurse>. Same caveat regarding accessors and hash
-keys applies.
-
-Final Note, because this might be on someone's mind. A common
-thing to do for Perl classes that are used for web services (and
-thus need to be serialized into JSON for transport) is to often
-implement a C<TO_JSON> method that provides an unblessed hash
-reference that most JSON encoding methods will happly serialize
-(or C<encode>). That is not unlike what is being done with
-C<o2h>, so future enhancements to C<o2h> may include detecting
-and calling C<TO_JSON> if the package blessing the reference
-C<can('TO_JSON').
+Access to C<Util::H2O::o2h>, but adjusts $Util::H2O::_PACKAGE_REGEX to
+accept package names that are generated by C<Util::H2O::More::baptise>.
 
 =item C<baptise_deeply, $hash_ref, $pkg, LIST>
 
